# Table of Contents

- [configuration-of-apptio-connector](<./configuration-of-apptio-connector.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Configuration of the Apptio Connector](<./Configuration-of-the-Apptio-Connector.md>)
  - [Before You Start](<./Configuration-of-the-Apptio-Connector/Before-You-Start.md>)
  - [Apptio Configuration JSON](<./Configuration-of-the-Apptio-Connector/Apptio-Configuration-JSON.md>)
  - [General Configuration parts](<./Configuration-of-the-Apptio-Connector/General-Configuration-parts.md>)
  - [apptioConnectionConfig](<./Configuration-of-the-Apptio-Connector/apptioConnectionConfig.md>)
  - [Read data from Apptio (download)](<./Configuration-of-the-Apptio-Connector/Read-data-from-Apptio-download.md>)
  - [Write data to Apptio (upload)](<./Configuration-of-the-Apptio-Connector/Write-data-to-Apptio-upload.md>)
  - [Was this page helpful?](<./Configuration-of-the-Apptio-Connector/Was-this-page-helpful.md>)
